package com.ruoyi.system.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AdminUser;
import com.ruoyi.system.service.IAdminUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户列表Controller
 * 
 * @author xiaoji
 * @date 2021-07-01
 */
@RestController
@RequestMapping("/system/GameUserList")
public class AdminUserController extends BaseController
{
    @Autowired
    private IAdminUserService adminUserService;

    /**
     * 查询用户列表列表
     */
    @PreAuthorize("@ss.hasPermi('system:GameUserList:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdminUser adminUser)
    {
        startPage();
        List<AdminUser> list = adminUserService.selectAdminUserList(adminUser);
        return getDataTable(list);
    }

    /**
     * 导出用户列表列表
     */
    @PreAuthorize("@ss.hasPermi('system:GameUserList:export')")
    @Log(title = "用户列表", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(AdminUser adminUser)
    {
        List<AdminUser> list = adminUserService.selectAdminUserList(adminUser);
        ExcelUtil<AdminUser> util = new ExcelUtil<AdminUser>(AdminUser.class);
        return util.exportExcel(list, "GameUserList");
    }

    /**
     * 获取用户列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:GameUserList:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(adminUserService.selectAdminUserById(id));
    }

    /**
     * 新增用户列表
     */
    @PreAuthorize("@ss.hasPermi('system:GameUserList:add')")
    @Log(title = "用户列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdminUser adminUser)
    {
        return toAjax(adminUserService.insertAdminUser(adminUser));
    }

    /**
     * 修改用户列表
     */
    @PreAuthorize("@ss.hasPermi('system:GameUserList:edit')")
    @Log(title = "用户列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdminUser adminUser)
    {
        return toAjax(adminUserService.updateAdminUser(adminUser));
    }

    /**
     * 删除用户列表
     */
    @PreAuthorize("@ss.hasPermi('system:GameUserList:remove')")
    @Log(title = "用户列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(adminUserService.deleteAdminUserByIds(ids));
    }
}
